package com.example.jwtbuilder

import com.example.model.Login
import io.smallrye.jwt.build.Jwt
import org.eclipse.microprofile.config.inject.ConfigProperty
import org.eclipse.microprofile.jwt.Claims
import java.time.Duration
import java.time.Instant
import javax.enterprise.context.RequestScoped

@RequestScoped
class TokenBuilder {
    @ConfigProperty(name = "mp.jwt.verify.issuer")
    internal lateinit var issuer: String

    @ConfigProperty(name = "my.token.expiration.hours")
    internal lateinit var expirationInHours: java.lang.Long

    fun buildToken(login: Login): String =
        Jwt.issuer(issuer)
            .upn(login.email)
            .groups(login.roles)
            .claim(Claims.full_name.name, login.firstName + " " + login.lastName)
            .claim(Claims.nickname.name, login.nickname)
            .claim(Claims.auth_time.name, Instant.now())
            .expiresIn(Duration.ofHours(expirationInHours.toLong()))
            .sign()
}