import requests
import json
import time

SUBJECT_URL = "http://subject-service-app-xbily-dev.apps.sandbox-m2.ll9k.p1.openshiftapps.com"
# SUBJECT_URL = "http://localhost:8080"


def print_all_subjects(token):
    print("\nAll subjects:")
    json_object = json.loads(get_all_subjects(token).text)
    print(json.dumps(json_object, indent=2))


def get_all_subjects(token):
    headers = {"Authorization": "Bearer " + token}
    return requests.get(SUBJECT_URL + '/subjects', headers=headers)


def get_subject_by_name(name, token):
    headers = {"Authorization": "Bearer " + token}
    response = requests.get(SUBJECT_URL + '/subjects/name/' + name, headers=headers)
    return json.loads(response.text)


def delete_all_subjects(token):
    start_time = time.time()
    headers = {"Authorization": "Bearer " + token}
    response = requests.delete(SUBJECT_URL + '/subjects', headers=headers)
    if response.status_code == 204:
        print("Deleted all subjects")
    else:
        print("Failed to delete all subjects: " + response.text)
    print("--- %s seconds ---" % (time.time() - start_time))


def delete_subject(id, token):
    start_time = time.time()
    headers = {"Authorization": "Bearer " + token}
    response = requests.delete(SUBJECT_URL + '/subjects/' + str(id), headers=headers)
    if response.status_code == 204:
        print("Deleted subject with id " + str(id))
    else:
        print("Failed to delete subject: " + response.text)
    print("--- %s seconds ---" % (time.time() - start_time))


def create_subject(name, teacher, student_limit, token):
    start_time = time.time()
    json_data = {
      "name": name,
      "teacher": teacher,
      "studentLimit": student_limit
    }
    headers = {"Authorization": "Bearer " + token}
    response = requests.post(SUBJECT_URL + '/subjects', json=json_data, headers=headers)

    if response.status_code == 201:
        print("Successfully created subject " + name + ", teacher " + str(teacher) + ", student limit " + str(student_limit))
    else:
        print("Failed to create subject: " + response.text + ".     Reason: " + response.reason)
    print("--- %s seconds ---" % (time.time() - start_time))
