import requests
import json
import time

USER_URL = "http://user-service-app-xbily-dev.apps.sandbox-m2.ll9k.p1.openshiftapps.com"
# USER_URL = "http://localhost:8081"


def print_all_users(token):
    print("\nAll users:")
    users = get_all_users(token)
    print(json.dumps(users, indent=2))


def get_all_users(token):
    headers = {"Authorization": "Bearer " + token}
    return json.loads(requests.get(USER_URL + '/users', headers=headers).text)


def get_user_by_nickname(nickname, token):
    headers = {"Authorization": "Bearer " + token}
    response = requests.get(USER_URL + '/users/nickname/' + nickname, headers=headers)
    return json.loads(response.text)


def get_all_students(token):
    users = get_all_users(token)
    return list(filter(lambda user: user["roleName"] == "Student", users))


def delete_all_users(token):
    start_time = time.time()
    headers = {"Authorization": "Bearer " + token}
    response = requests.delete(USER_URL + '/users', headers=headers)
    if response.status_code == 204:
        print("Deleted all users")
    else:
        print("Failed to delete all users: " + response.text)
    print("--- %s seconds ---" % (time.time() - start_time))


def delete_user(id, token):
    start_time = time.time()
    headers = {"Authorization": "Bearer " + token}
    response = requests.delete(USER_URL + '/users/' + str(id), headers=headers)
    if response.status_code == 204:
        print("Deleted user with id " + str(id))
    else:
        print("Failed to delete user: " + response.text)
    print("--- %s seconds ---" % (time.time() - start_time))


def create_user(nickname, first_name, last_name, role_name, password_hash, token):
    start_time = time.time()
    json_data = {
      "nickname": nickname,
      "firstName": first_name,
      "lastName": last_name,
      "roleName": role_name,
      "passwordHash": password_hash
    }
    headers = {"Authorization": "Bearer " + token}
    response = requests.post(USER_URL + '/users', json=json_data, headers=headers)

    if response.status_code == 201:
        print("Successfully created user: nickname " + nickname + ", firstName " + first_name + ", lastName " + last_name + ", roleName " + role_name + ", passwordHash " + password_hash)
    else:
        print("Failed to create user: " + response.text + ".     Reason: " + response.reason)
    print("--- %s seconds ---" % (time.time() - start_time))
