package org.acme;

import io.quarkus.test.common.http.TestHTTPEndpoint;
import io.quarkus.test.junit.QuarkusTest;
import io.quarkus.test.security.TestSecurity;
import io.restassured.http.ContentType;
import org.acme.data.Subject;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import javax.inject.Inject;

import java.util.List;

import static io.restassured.RestAssured.given;
import static io.restassured.RestAssured.when;
import static org.hamcrest.CoreMatchers.containsString;
import static org.hamcrest.CoreMatchers.is;

@QuarkusTest
@TestHTTPEndpoint(SubjectResource.class)
@TestSecurity(authorizationEnabled = false)
public class SubjectResourceTest {

    @Inject
    SubjectResource subjectResource;

    @BeforeEach
    public void setup() {
        subjectResource.deleteAll();
    }

    @Test
    public void testGetSubjectsWithNoSubjectCreated() {
        when().get()
                .then()
                .statusCode(200)
                .body(is("[]"));
    }

    @Test
    public void testCreateSubject() {
        given()
                .body(
                    "{\"name\":\"PA217\"," +
                    "\"teacher\":1," +
                    "\"studentLimit\":40}")
                .contentType(ContentType.JSON)
                .when().post()
                        .then().statusCode(201);


        List<Subject> subjects = subjectResource.list();

        Assertions.assertEquals(1, subjects.size());
        Assertions.assertEquals("PA217", subjects.get(0).name);
        Assertions.assertEquals(1, subjects.get(0).teacher);
        Assertions.assertEquals(40, subjects.get(0).studentLimit);
    }

    @Test
    public void testGetSubjectByName() {
        Subject subject = new Subject();
        subject.name = "PA217";
        subject.teacher = 1;
        subject.studentLimit = 40;
        subjectResource.create(subject);

        given().pathParam("name", "PA217")
                .when().get("/name/{name}")
                .then()
                .statusCode(200)
                .body(containsString(
                    "\"name\":\"PA217\"," +
                    "\"teacher\":1," +
                    "\"studentLimit\":40"));
    }

    @Test
    public void testDeleteSubject() {
        Subject subject = new Subject();
        subject.name = "PA217";
        subject.teacher = 1;
        subject.studentLimit = 40;
        subjectResource.create(subject);

        given().pathParam("id", subject.id)
                .when().delete("/{id}")
                .then()
                .statusCode(204);

        List<Subject> subjects = subjectResource.list();
        Assertions.assertEquals(0, subjects.size());
    }
}
