package org.acme;

import io.quarkus.test.common.http.TestHTTPEndpoint;
import io.quarkus.test.junit.QuarkusTest;
import io.quarkus.test.security.TestSecurity;
import io.restassured.http.ContentType;
import org.acme.data.Role;
import org.acme.data.UserX;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import javax.inject.Inject;

import java.util.List;

import static io.restassured.RestAssured.given;
import static io.restassured.RestAssured.when;
import static org.hamcrest.CoreMatchers.containsString;
import static org.hamcrest.CoreMatchers.is;

@QuarkusTest
@TestHTTPEndpoint(UserResource.class)
@TestSecurity(authorizationEnabled = false)
public class UserResourceTest {

    @Inject
    UserResource userResource;


    @BeforeEach
    public void setup() {
        userResource.deleteAll();
    }

    @Test
    public void testGetUsersWithNoUsersCreated() {
        when().get()
                .then()
                .statusCode(200)
                .body(is("[]"));
    }

    @Test
    public void testCreateUser() {
        given()
                .body(
                    "{\"nickname\":\"jenda\"," +
                    "\"email\":\"jenda@mail.com\"," +
                    "\"firstName\":\"Jonh\"," +
                    "\"lastName\":\"Deer\"," +
                    "\"roleName\":\"Student\"}")
                .contentType(ContentType.JSON)
                .when().post()
                        .then().statusCode(201);

        List<UserX> users = userResource.list();

        Assertions.assertEquals(1, users.size());
        Assertions.assertEquals("jenda", users.get(0).nickname);
        Assertions.assertEquals("jenda@mail.com", users.get(0).email);
        Assertions.assertEquals("Jonh", users.get(0).firstName);
        Assertions.assertEquals("Deer", users.get(0).lastName);
        Assertions.assertEquals(Role.Student, users.get(0).roleName);
    }

    @Test
    public void testGetUserByNickname() {
        UserX user = new UserX();
        user.roleName = Role.Student;
        user.nickname = "jenda";
        user.email = "jenda@mail.com";
        user.firstName = "Jonh";
        user.lastName = "Deer";
        userResource.create(user);

        given().pathParam("nickname", "jenda")
                .when().get("/nickname/{nickname}")
                .then()
                .statusCode(200)
                .body(containsString(
                    "\"nickname\":\"jenda\"," +
                    "\"email\":\"jenda@mail.com\"," +
                    "\"firstName\":\"Jonh\"," +
                    "\"lastName\":\"Deer\"," +
                    "\"roleName\":\"Student\""));
    }

    @Test
    public void testDeleteUser() {
        UserX user = new UserX();
        user.roleName = Role.Student;
        user.nickname = "jenda";
        user.email = "jenda@mail.com";
        user.firstName = "Jonh";
        user.lastName = "Deer";
        userResource.create(user);

        given().pathParam("id", user.id)
                .when().delete("/{id}")
                .then()
                .statusCode(204);

        List<UserX> users = userResource.list();
        Assertions.assertEquals(0, users.size());
    }
}
